<!--
SPDX-FileCopyrightText: AISEC Pentesting Team

SPDX-License-Identifier: CC0-1.0
-->

# Changelog

Changelog entries are maintained in Github releases here: https://github.com/Fraunhofer-AISEC/gallia/releases
